# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "0.4.0"
FULL_VERSION = "0.4.0.1.0"

ARCHITECTURY_VERSION = "6.5.85"
ASM_VERSION = "9.4"
CARDINAL_COMPONENTS_VERSION = "5.0.2"
CCA_VERSION = "5.0.2"
CURSEFORGE_ID = ""
ENABLED_PLATFORMS = "fabric,forge"
ENTITY_REACH_VERSION = "2.3.0"
FABRIC_API_VERSION = "0.77.0+1.19.2"
FABRIC_KOTLIN_VERSION = "1.9.0+kotlin.1.8.0"
FABRIC_LOADER_VERSION = "0.15.11"
FORGE_KOTLIN_VERSION = "3.12.0"
FORGE_VERSION = "1.19.2-43.2.11"
GECKOLIB_VERSION = "3.1.40"
GLOOP_VERSION = "0.2.0"
HEXAL_VERSION = "0.2.18"
HEXCASTING_VERSION = "0.10.3"
JETBRAINS_ANNOTATIONS_VERSION = "23.0.0"
KOTLIN_STDLIB_DEFAULT_DEPENDENCY = "false"
MAVEN_GROUP = "net.beholderface.oneironaut"
MINECRAFT_VERSION = "1.19.2"
MIXIN_EXTRAS_VERSION = "0.2.0-beta.9"
MOD_I_D = "oneironaut"
MOD_VERSION = "0.4.0"
MODRINTH_ID = ""
ORG_GRADLE_JVMARGS = "-Xmx2048M"
PATCHOULI_VERSION = "77"
PAUCAL_VERSION = "0.5.0"
SERIALIZATION_HOOKS_VERSION = "0.3.24"
TRINKETS_VERSION = "3.4.1"
WNBOI_VERSION = "0.0.4"
YARN_MAPPINGS_VERSION = "1.19.2+build.28:v2"
